2ab19ca505
- Complete translation tables for cudaError <-> hipError_t.
- Remove some odd errors that were not correctly translated or not used.
- Add HIPCHECK_API to test infrastructure. Used for negative testing
an API ; if a mismatch occurs it shows the expected return error
code. Can also print a warning rather than error.
- Enable hipMemoryAllocate on NV system, and review error coded.
- Add hipErrorName to nvcc.
Change-Id: I680427dcf32a5796d5913cf9e7f3b4c6f6b91599
Conflicts:
tests/src/CMakeLists.txt
Bug fixes and improved docs for hipFree and hipHostFree.
- Passing NULL pointer initialized runtime and return hipSuccess
(not an error like before).
- add negative test for this. (hipMemoryAllocate, improved)
- Match NVCC errors for invalid pointers, add to test.
- Update hipFree and hipHostFree docs.
- hipGetDevicePointer always set *devicePointer=NULL, even for
invalid flags.
- Gate shared memory usage on specific HCC work-week.
Change-Id: I533b4fd3280a3d6cdbf05eb768976f0c7506c012
51 řádky
2.1 KiB
C++
51 řádky
2.1 KiB
C++
/*
|
|
Copyright (c) 2015-2016 Advanced Micro Devices, Inc. All rights reserved.
|
|
Permission is hereby granted, free of charge, to any person obtaining a copy
|
|
of this software and associated documentation files (the "Software"), to deal
|
|
in the Software without restriction, including without limitation the rights
|
|
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
|
copies of the Software, and to permit persons to whom the Software is
|
|
furnished to do so, subject to the following conditions:
|
|
The above copyright notice and this permission notice shall be included in
|
|
all copies or substantial portions of the Software.
|
|
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANNTY OF ANY KIND, EXPRESS OR
|
|
IMPLIED, INNCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
|
FITNNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
|
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANNY CLAIM, DAMAGES OR OTHER
|
|
LIABILITY, WHETHER INN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
|
OUT OF OR INN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
|
THE SOFTWARE.
|
|
*/
|
|
#include"test_common.h"
|
|
|
|
#define SIZE 1024*1024*256
|
|
|
|
int main(){
|
|
float *Ad, *B, *Bd, *Bm, *C, *Cd;
|
|
B = (float*)malloc(SIZE);
|
|
hipMalloc((void**)&Ad, SIZE);
|
|
hipHostMalloc((void**)&B, SIZE);
|
|
hipHostMalloc((void**)&Bd, SIZE, hipHostMallocDefault);
|
|
hipHostMalloc((void**)&Bm, SIZE, hipHostMallocMapped);
|
|
hipHostMalloc((void**)&C, SIZE, hipHostMallocMapped);
|
|
|
|
hipHostGetDevicePointer((void**)&Cd, C, 0/*flags*/);
|
|
|
|
HIPCHECK_API(hipFree(Ad) , hipSuccess);
|
|
HIPCHECK_API(hipHostFree(Ad) , hipErrorInvalidValue);
|
|
|
|
HIPCHECK_API(hipFree(B) , hipErrorInvalidDevicePointer); // try to hipFree on malloced memory
|
|
HIPCHECK_API(hipFree(Bd) , hipErrorInvalidDevicePointer);
|
|
HIPCHECK_API(hipFree(Bm) , hipErrorInvalidDevicePointer);
|
|
HIPCHECK_API(hipHostFree(Bd) , hipSuccess);
|
|
HIPCHECK_API(hipHostFree(Bm) , hipSuccess);
|
|
|
|
HIPCHECK_API(hipFree(C) , hipErrorInvalidDevicePointer);
|
|
HIPCHECK_API(hipHostFree(C) , hipSuccess);
|
|
|
|
|
|
HIPCHECK_API(hipFree(NULL) , hipSuccess);
|
|
HIPCHECK_API(hipHostFree(NULL) , hipSuccess);
|
|
passed();
|
|
}
|